summaryrefslogtreecommitdiffstats
path: root/kmail/kmfoldercachedimap.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-02-16 20:17:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-02-16 20:17:18 +0000
commitf4fae92b6768541e2952173c3d4b09040f95bf7e (patch)
treed8c5d93232235cd635f3310b4d95490df181ba2d /kmail/kmfoldercachedimap.cpp
parent125c0a08265b75a133644d3b55f47e37c919f45d (diff)
downloadtdepim-f4fae92b6768541e2952173c3d4b09040f95bf7e.tar.gz
tdepim-f4fae92b6768541e2952173c3d4b09040f95bf7e.zip
Moved kpilot from kdepim to applications, as the core Trinity libraries should not contain hardware-dependent software
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1221127 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmail/kmfoldercachedimap.cpp')
-rw-r--r--kmail/kmfoldercachedimap.cpp32
1 files changed, 16 insertions, 16 deletions
diff --git a/kmail/kmfoldercachedimap.cpp b/kmail/kmfoldercachedimap.cpp
index a1c71726..61e155ac 100644
--- a/kmail/kmfoldercachedimap.cpp
+++ b/kmail/kmfoldercachedimap.cpp
@@ -49,7 +49,7 @@ using KMail::AccountManager;
#include "kmglobal.h"
#include "acljobs.h"
#include "broadcaststatus.h"
-using KPIM::BroadcastStatus;
+using KPIM::BroadcasStatus;
#include "progressmanager.h"
using KMail::CachedImapJob;
@@ -549,7 +549,7 @@ int KMFolderCachedImap::addMsgInternal( KMMessage* msg, bool newMail,
if ( imapPath() == "/INBOX/" )
filter = true;
} else {
- if ( GlobalSettings::filterSourceFolders().contains( folder()->id() ) )
+ if ( GlobalSettings::filterSourceFolders().tqcontains( folder()->id() ) )
filter = true;
}
if ( filter )
@@ -744,7 +744,7 @@ void KMFolderCachedImap::slotTroubleshoot()
TQString s2 = i18n("&Refresh");
if( KMessageBox::warningContinueCancel( 0, str, s1, s2 ) ==
KMessageBox::Continue )
- account()->invalidateIMAPFolders( this );
+ account()->tqinvalidateIMAPFolders( this );
} else {
// Rebuild index file
switch ( rc ) {
@@ -1394,11 +1394,11 @@ void KMFolderCachedImap::buildSubFolderList()
while( node ) {
if( !node->isDir() ) {
KMFolderCachedImap* storage = static_cast<KMFolderCachedImap*>(static_cast<KMFolder*>(node)->storage());
- const bool folderIsNew = mNewlyCreatedSubfolders.contains( TQGuardedPtr<KMFolderCachedImap>( storage ) );
+ const bool folderIsNew = mNewlyCreatedSubfolders.tqcontains( TQGuardedPtr<KMFolderCachedImap>( storage ) );
// Only sync folders that have been accepted by the server
if ( !storage->imapPath().isEmpty()
// and that were not just deleted from it
- && !foldersForDeletionOnServer.contains( storage->imapPath() ) ) {
+ && !foldersForDeletionOnServer.tqcontains( storage->imapPath() ) ) {
if ( mRecurse || folderIsNew ) {
mSubfoldersForSync << storage;
}
@@ -1618,18 +1618,18 @@ void KMFolderCachedImap::slotImapStatusChanged(KMFolder* folder, const TQString&
}
// This is not perfect, what if the status didn't really change? Oh well ...
-void KMFolderCachedImap::setStatus( int idx, KMMsgStatus status, bool toggle)
+void KMFolderCachedImap::seStatus( int idx, KMMsgStatus status, bool toggle)
{
- KMFolderMaildir::setStatus( idx, status, toggle );
+ KMFolderMaildir::seStatus( idx, status, toggle );
const KMMsgBase *msg = getMsgBase( idx );
Q_ASSERT( msg );
if ( msg )
mUIDsOfLocallyChangedStatuses.insert( msg->UID() );
}
-void KMFolderCachedImap::setStatus(TQValueList<int>& ids, KMMsgStatus status, bool toggle)
+void KMFolderCachedImap::seStatus(TQValueList<int>& ids, KMMsgStatus status, bool toggle)
{
- KMFolderMaildir::setStatus(ids, status, toggle);
+ KMFolderMaildir::seStatus(ids, status, toggle);
for (TQValueList<int>::iterator it = ids.begin(); it != ids.end(); it++ ) {
const KMMsgBase *msg = getMsgBase( *it );
Q_ASSERT( msg );
@@ -1907,7 +1907,7 @@ void KMFolderCachedImap::slotGetMessagesData(KIO::Job * job, const TQByteArray &
kdDebug(5006) << "Looking at uid " << uid << " high water is: " << lastUid() << " we should delete it" << endl;
#endif
// double check we deleted it since the last sync
- if ( mDeletedUIDsSinceLastSync.contains(uid) ) {
+ if ( mDeletedUIDsSinceLastSync.tqcontains(uid) ) {
if ( mUserRightsState != KMail::ACLJobs::Ok || ( mUserRights & KMail::ACLJobs::Delete ) ) {
#if MAIL_LOSS_DEBUGGING
kdDebug(5006) << "message with uid " << uid << " is gone from local cache. Must be deleted on server!!!" << endl;
@@ -1941,8 +1941,8 @@ void KMFolderCachedImap::slotGetMessagesData(KIO::Job * job, const TQByteArray &
kdDebug(5006) << "Looking at uid " << uid << " high water is: " << lastUid() << " we should download it" << endl;
#endif
// The message is new since the last sync, but we might have just uploaded it, in which case
- // the uid map already contains it.
- if ( !uidMap.contains( uid ) ) {
+ // the uid map already tqcontains it.
+ if ( !uidMap.tqcontains( uid ) ) {
mMsgsForDownload << KMail::CachedImapJob::MsgForDownload(uid, flags, size);
if( imapPath() == "/INBOX/" )
mUidsForDownload << uid;
@@ -2596,7 +2596,7 @@ void KMFolderCachedImap::resetSyncState()
KPIM::ProgressItem *progressItem = mAccount->mailCheckProgressItem();
TQString str = i18n("Aborted");
if (progressItem)
- progressItem->setStatus( str );
+ progressItem->seStatus( str );
emit statusMsg( str );
emit syncStateChanged();
}
@@ -2620,7 +2620,7 @@ void KMFolderCachedImap::newState( int progress, const TQString& syncStatus )
else
str = TQString( "%1: %2" ).arg( label() ).arg( syncStatus );
if( progressItem )
- progressItem->setStatus( str );
+ progressItem->seStatus( str );
emit statusMsg( str );
}
if( progressItem )
@@ -2944,7 +2944,7 @@ KMFolderCachedImap::slotSetAnnotationResult(KIO::Job *job)
bool cont = true;
if ( job->error() ) {
// Don't show error if the server doesn't support ANNOTATEMORE and this folder only contains mail
if ( job->error() == KIO::ERR_UNSUPPORTED_ACTION && contentsType() == ContentsTypeMail ) {
if (mAccount->slave()) mAccount->removeJob(job);
} else {
@@ -3095,7 +3095,7 @@ KMCommand* KMFolderCachedImap::rescueUnsyncedMessages()
break;
// create subfolder for this incident
- TQDate today = TQDate::currentDate();
+ TQDate today = TQDate::tqcurrentDate();
TQString baseName = folder()->label() + "-" + TQString::number( today.year() )
+ (today.month() < 10 ? "0" : "" ) + TQString::number( today.month() )
+ (today.day() < 10 ? "0" : "" ) + TQString::number( today.day() );
@@ -2944,7 +2944,7 @@ KMFolderCachedImap::slotSetAnnotationResult(KIO::Job *job)
bool cont = true;
if ( job->error() ) {
- // Don't show error if the server doesn't support ANNOTATEMORE and this folder only contains mail
+ // Don't show error if the server doesn't support ANNOTATEMORE and this folder only tqcontains mail
if ( job->error() == KIO::ERR_UNSUPPORTED_ACTION && contentsType() == ContentsTypeMail ) {
if (mAccount->slave()) mAccount->removeJob(job);